"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolveBurnMasterEdition = exports.resolveTokenProgramForNonProgrammables = exports.resolveAuthorizationRulesProgram = exports.resolveDestinationTokenRecord = exports.resolveTokenRecord = exports.resolveOptionalTokenOwner = exports.resolveCreateV1Bytes = exports.resolveCreators = exports.resolvePrintSupply = exports.resolveDecimals = exports.resolveMasterEditionForProgrammables = exports.resolveMasterEdition = exports.resolveCollectionDetails = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const mpl_essentials_1 = require("@metaplex-foundation/mpl-essentials");
const digitalAsset_1 = require("../digitalAsset");
const generated_1 = require("../generated");
const resolveCollectionDetails = (context, accounts, args, programId) => args.isCollection ? (0, umi_1.some)((0, generated_1.collectionDetails)('V1', { size: 0 })) : (0, umi_1.none)();
exports.resolveCollectionDetails = resolveCollectionDetails;
const resolveMasterEdition = (context, accounts, args, programId) => (0, digitalAsset_1.isNonFungible)(args.tokenStandard)
    ? (0, generated_1.findMasterEditionPda)(context, { mint: (0, umi_1.publicKey)(accounts.mint) })
    : programId;
exports.resolveMasterEdition = resolveMasterEdition;
const resolveMasterEditionForProgrammables = (context, accounts, args, programId) => (0, digitalAsset_1.isNonFungible)(args.tokenStandard) && (0, digitalAsset_1.isProgrammable)(args.tokenStandard)
    ? (0, generated_1.findMasterEditionPda)(context, { mint: (0, umi_1.publicKey)(accounts.mint) })
    : programId;
exports.resolveMasterEditionForProgrammables = resolveMasterEditionForProgrammables;
const resolveDecimals = (context, accounts, args, programId) => ((0, digitalAsset_1.isNonFungible)(args.tokenStandard) ? (0, umi_1.none)() : (0, umi_1.some)(0));
exports.resolveDecimals = resolveDecimals;
const resolvePrintSupply = (context, accounts, args, programId) => (0, digitalAsset_1.isNonFungible)(args.tokenStandard) ? (0, umi_1.some)((0, generated_1.printSupply)('Zero')) : (0, umi_1.none)();
exports.resolvePrintSupply = resolvePrintSupply;
const resolveCreators = (context, accounts, args, programId) => (0, umi_1.some)([
    { address: (0, umi_1.publicKey)(accounts.authority), share: 100, verified: true },
]);
exports.resolveCreators = resolveCreators;
const resolveCreateV1Bytes = (context, accounts, args, programId) => {
    const base = (0, mpl_essentials_1.getMintSize)() + (0, generated_1.getMetadataSize)() + 2 * umi_1.ACCOUNT_HEADER_SIZE;
    if ((0, digitalAsset_1.isNonFungible)(args.tokenStandard)) {
        return base + (0, generated_1.getMasterEditionSize)() + umi_1.ACCOUNT_HEADER_SIZE;
    }
    return base;
};
exports.resolveCreateV1Bytes = resolveCreateV1Bytes;
const resolveOptionalTokenOwner = (context, accounts, args, programId) => (accounts.token ? programId : context.identity.publicKey);
exports.resolveOptionalTokenOwner = resolveOptionalTokenOwner;
const resolveTokenRecord = (context, accounts, args, programId) => (0, digitalAsset_1.isProgrammable)(args.tokenStandard) && accounts.token
    ? (0, generated_1.findTokenRecordPda)(context, {
        mint: (0, umi_1.publicKey)(accounts.mint),
        token: accounts.token,
    })
    : programId;
exports.resolveTokenRecord = resolveTokenRecord;
const resolveDestinationTokenRecord = (context, accounts, args, programId) => (0, digitalAsset_1.isProgrammable)(args.tokenStandard)
    ? (0, generated_1.findTokenRecordPda)(context, {
        mint: (0, umi_1.publicKey)(accounts.mint),
        token: accounts.destinationToken,
    })
    : programId;
exports.resolveDestinationTokenRecord = resolveDestinationTokenRecord;
const resolveAuthorizationRulesProgram = (context, accounts, args, programId) => accounts.authorizationRules
    ? {
        ...context.programs.getPublicKey('mplTokenAuthRules', 'auth9SigNpDKz4sJJ1DfCTuZrZNSAgh9sFD3rboVmgg'),
        isWritable: false,
    }
    : programId;
exports.resolveAuthorizationRulesProgram = resolveAuthorizationRulesProgram;
const resolveTokenProgramForNonProgrammables = (context, accounts, args, programId) => !(0, digitalAsset_1.isProgrammable)(args.tokenStandard)
    ? {
        ...context.programs.getPublicKey('splToken', 'TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA'),
        isWritable: false,
    }
    : programId;
exports.resolveTokenProgramForNonProgrammables = resolveTokenProgramForNonProgrammables;
const resolveBurnMasterEdition = (context, accounts, args, programId) => (0, umi_1.samePublicKey)(accounts.masterEditionMint, programId)
    ? programId
    : (0, generated_1.findMasterEditionPda)(context, {
        mint: (0, umi_1.publicKey)(accounts.masterEditionMint),
    });
exports.resolveBurnMasterEdition = resolveBurnMasterEdition;
//# sourceMappingURL=resolvers.js.map